## $Id: product.py 12064 2014-11-26 15:32:41Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
These are the products (e.g. licenses).
"""
import grok
from time import time
from grok import index
from hurry.workflow.interfaces import IWorkflowInfo, IWorkflowState
from zope.event import notify
from zope.component import getUtility
from zope.component.interfaces import IFactory
from zope.interface import implementedBy
from zope.i18n import translate
from waeup.ikoba.interfaces import IIkobaUtils
from waeup.ikoba.interfaces import MessageFactory as _
from waeup.ikoba.utils.helpers import attrs_to_fields, get_current_principal
from waeup.ikoba.utils.logger import Logger
from waeup.ikoba.products.interfaces import (
    IProduct, IProduct,)

class Product(grok.Container, Logger):
    """This is a product.
    """
    grok.implements(IProduct)
    grok.provides(IProduct)
    grok.baseclass()

    logger_name = 'waeup.ikoba.${sitename}.products'
    logger_filename = 'products.log'
    logger_format_str = '"%(asctime)s","%(user)s",%(message)s'

    def logger_info(self, comment=None):
        """Get the logger's info method.
        """
        self.logger.info('%s' % comment)
        return

Product = attrs_to_fields(Product)


class ProductFactory(grok.GlobalUtility):
    """A factory for products.
    """
    grok.implements(IFactory)
    grok.name(u'waeup.Product')
    title = u"Create a new product.",
    description = u"This factory instantiates new products."

    def __call__(self, *args, **kw):
        return Product(*args, **kw)

    def getInterfaces(self):
        return implementedBy(Product)
